@@ -353,6 +353,7 @@ void instancedefaults(objinstptr newinst, objectptr thisobj, int x, int y)
    newinst->position.y = y;
    newinst->rotation = 0;
    newinst->scale = 1.0;
+   newinst->style = LINE_INVARIANT;
    newinst->thisobject = thisobj;
    newinst->color = areawin->color;
    newinst->params = NULL;
@@ -921,25 +922,6 @@ Boolean labeltext(int keypressed, char *clientdata)
    /* Redraw the label */
 
    if (do_redraw) {
-      short beglength;
-
-      tmpext = ULength(curlabel, areawin->topinstance, curlabel->scale,
-		areawin->textpos, NULL);
-      beglength = tmpext.width;
-	
-      tmpext = ULength(curlabel, areawin->topinstance, curlabel->scale,
-		0, NULL);
-      tmplength = tmpext.width;
-      tmpheight = (short)(curlabel->scale * TEXTHEIGHT);
-      areawin->origin.x = curlabel->position.x + (curlabel->justify & NOTLEFT
-	  ? (curlabel->justify & RIGHT ? 0 : tmplength / 2) : tmplength)
-	  - (tmplength - beglength);
-      areawin->origin.y = curlabel->position.y + (curlabel->justify &
-	  NOTBOTTOM ? (curlabel->justify & TOP ? -tmpheight : -tmpheight / 2)
-	  : 0);
-      if (curlabel->pin)
-         pinadjust(curlabel->justify, &(areawin->origin.x),
-		&(areawin->origin.y), 1);
       XcSetFunction(GXcopy);
       redrawtext(curlabel);
    }
@@ -1085,7 +1067,7 @@ void splinebutton(int x, int y)
 
    XcSetXORFg(areawin->color, BACKGROUND);
    XcSetFunction(GXxor);
-   UDrawSpline(*newspline);
+   UDrawSpline(*newspline, xobjs.pagelist[areawin->page]->wirewidth);
 
    xcAddEventHandler(areawin->area, PointerMotionMask, False,
         (xcEventHandler)trackelement, NULL);
@@ -1230,7 +1212,7 @@ void arcbutton(int x, int y)
 
    XcSetXORFg(areawin->color, BACKGROUND);
    XcSetFunction(GXxor);
-   UDrawArc(*newarc);
+   UDrawArc(*newarc, xobjs.pagelist[areawin->page]->wirewidth);
    UDrawXLine((*newarc)->position, (*newarc)->position);
 
    xcAddEventHandler(areawin->area, PointerMotionMask, False,
@@ -1256,7 +1238,7 @@ void trackarc(xcWidget w, caddr_t clientdata, caddr_t calldata)
    u2u_snap(&newpos);
    if (areawin->save.x == newpos.x && areawin->save.y == newpos.y) return;
 
-   UDrawArc(newarc);
+   UDrawArc(newarc, xobjs.pagelist[areawin->page]->wirewidth);
    UDrawXLine(areawin->save, newarc->position);
 
    cycle = (newarc->cycle == NULL) ? -1 : newarc->cycle->number;
@@ -1298,7 +1280,7 @@ void trackarc(xcWidget w, caddr_t clientdata, caddr_t calldata)
 
    calcarc(newarc);
 
-   UDrawArc(newarc);
+   UDrawArc(newarc, xobjs.pagelist[areawin->page]->wirewidth);
    UDrawXLine(newpos, newarc->position);
    printpos(newpos.x, newpos.y);
 
@@ -1354,7 +1336,7 @@ void boxbutton(int x, int y)
 
    XcSetXORFg(areawin->color, BACKGROUND);
    XcSetFunction(GXxor);
-   UDrawPolygon(*newbox);
+   UDrawPolygon(*newbox, xobjs.pagelist[areawin->page]->wirewidth);
 
    xcAddEventHandler(areawin->area, PointerMotionMask, False,
         (xcEventHandler)trackbox, NULL);
@@ -1378,13 +1360,13 @@ void trackbox(xcWidget w, caddr_t clientdata, caddr_t calldata)
 
    if (areawin->save.x == newpos.x && areawin->save.y == newpos.y) return;
 
-   UDrawPolygon(newbox);
+   UDrawPolygon(newbox, xobjs.pagelist[areawin->page]->wirewidth);
 
    pointptr = newbox->points + 1; pointptr->y = newpos.y;
    pointptr++; pointptr->y = newpos.y; pointptr->x = newpos.x;
    pointptr++; pointptr->x = newpos.x;
    
-   UDrawPolygon(newbox);
+   UDrawPolygon(newbox, xobjs.pagelist[areawin->page]->wirewidth);
    printpos(newpos.x, newpos.y);
 
    areawin->save.x = newpos.x;
@@ -1422,12 +1404,12 @@ void trackwire(xcWidget w, caddr_t clientdata, caddr_t calldata)
 
    if (areawin->save.x != newpos.x || areawin->save.y != newpos.y) {
       tpoint = newwire->points + newwire->number - 1;
-      UDrawPolygon(newwire);
+      UDrawPolygon(newwire, xobjs.pagelist[areawin->page]->wirewidth);
       if (areawin->manhatn && (newwire->number > 2))
 	 manhattanize(&newpos, newwire, -1, TRUE);
       tpoint->x = newpos.x;
       tpoint->y = newpos.y;
-      UDrawPolygon(newwire);
+      UDrawPolygon(newwire, xobjs.pagelist[areawin->page]->wirewidth);
       areawin->save.x = newpos.x;
       areawin->save.y = newpos.y;
       printpos(newpos.x, newpos.y);
@@ -1466,7 +1448,7 @@ void startwire(XPoint *userpt)
 
    XcSetXORFg(areawin->color, BACKGROUND);
    XcSetFunction(GXxor);
-   UDrawPolygon(*newwire);
+   UDrawPolygon(*newwire, xobjs.pagelist[areawin->page]->wirewidth);
 
    xcAddEventHandler(areawin->area, PointerMotionMask, False,
           (xcEventHandler)trackwire, NULL);
@@ -1803,7 +1785,7 @@ void unjoin()
 
          /* undraw the path */
       
-         UDrawPath(oldpath);
+         UDrawPath(oldpath, xobjs.pagelist[areawin->page]->wirewidth);
       
          /* move components to the top level */
 
@@ -1825,7 +1807,7 @@ void unjoin()
 	 /* Method to break a polygon, in lieu of the edit-mode	*/
 	 /* polygon break that was removed.			*/
          oldpoly = SELTOPOLY(selectobj);
-         UDrawPolygon(oldpoly);
+         UDrawPolygon(oldpoly, xobjs.pagelist[areawin->page]->wirewidth);
 
 	 /* Get the point nearest the cursor, and break at that point */
          cycle = closepoint(oldpoly, &areawin->save);
@@ -2195,7 +2177,7 @@ void wire_op(int op, int x, int y)
    newwire = TOPOLY(EDITPART);
 
    /* This undraws the wire */
-   UDrawPolygon(newwire);
+   UDrawPolygon(newwire, xobjs.pagelist[areawin->page]->wirewidth);
 
    if (areawin->attachto >= 0) {
       XPoint apos;
@@ -2268,7 +2250,7 @@ void wire_op(int op, int x, int y)
 	 if (!nonnetwork(newwire)) invalidate_netlist(topobject);
 	 register_for_undo(XCF_Wire, UNDO_MORE, areawin->topinstance, newwire);
       }
-      UDrawPolygon(newwire);
+      UDrawPolygon(newwire, xobjs.pagelist[areawin->page]->wirewidth);
       if (op == XCF_Cancel_Last)
 	 checkwarp(newwire->points + newwire->number - 1);
    }
