@@ -532,10 +532,7 @@ void user_to_window(XPoint upt, XPoint *wpt)
 
 int UGetCTMRotation(Matrix *ctm)
 {
-   float topscale = UTopScale();
-   float rads = (float)atan2((double)(ctm->d / topscale),
-			(double)(ctm->a / topscale));
-
+   float rads = (float)atan2((double)(ctm->d), (double)(ctm->a));
    return (int)(rads / RADFAC);
 }
 
@@ -1185,7 +1182,7 @@ void labelbbox(labelptr labox, XPoint *npoints, objinstptr callinst)
    TextExtents tmpext;
    short j;
 
-   tmpext = ULength(labox, callinst, 0.0, 0, NULL);
+   tmpext = ULength(labox, callinst, 0, NULL);
    points[0].x = points[1].x = (labox->justify & NOTLEFT ? 
 	       (labox->justify & RIGHT ? -tmpext.width :
 		-tmpext.width / 2) : 0);
@@ -1900,10 +1897,10 @@ void UDrawTextLine(labelptr curlabel, short tpos)
    SetFunction(dpy, areawin->gc, GXxor);
    SetForeground(dpy, areawin->gc, AUXCOLOR ^ BACKGROUND);
 
-   tmpext = ULength(curlabel, areawin->topinstance, 0.0, tpos, NULL);
+   tmpext = ULength(curlabel, areawin->topinstance, tpos, NULL);
    xdist = tmpext.width;
    xbase = tmpext.base;
-   tmpext = ULength(curlabel, areawin->topinstance, 0.0, 0, NULL);
+   tmpext = ULength(curlabel, areawin->topinstance, 0, NULL);
 
    points[0].x = (tmpjust & NOTLEFT ?
         (tmpjust & RIGHT ? -tmpext.width : -tmpext.width >> 1) : 0)
@@ -2040,7 +2037,7 @@ float UDrawRescaleBox(XPoint *corner)
 	    newscale = (float)((int)(newscale * snapstep)) / snapstep;
 	    if (newscale < (1.0 / snapstep)) newscale = (1.0 / snapstep);
 	 }
-	 else if (newscale < 0.1 * rgraph->scale) newscale = 0.1 * rgraph->scale;
+	 else if (newscale < 0.1 * rlab->scale) newscale = 0.1 * rlab->scale;
 	 rlab->scale = newscale;
 	 labelbbox(rlab, newpoints, areawin->topinstance);
 	 rlab->scale = savescale;
@@ -2100,7 +2097,7 @@ float UDrawRescaleBox(XPoint *corner)
 	    newscale = (float)((int)(newscale * snapstep)) / snapstep;
 	    if (newscale < (1.0 / snapstep)) newscale = (1.0 / snapstep);
 	 }
-	 else if (newscale < 0.1 * rgraph->scale) newscale = 0.1 * rgraph->scale;
+	 else if (newscale < 0.1 * rinst->scale) newscale = 0.1 * rinst->scale;
 	 rinst->scale = newscale;
 	 objinstbbox(rinst, newpoints, 0);
 	 rinst->scale = savescale;
@@ -2153,7 +2150,7 @@ void strokepath(XPoint *pathlist, short number, short style, float width)
    float        tmpwidth;
    short	minwidth;
 
-   tmpwidth = UTopTransScale(xobjs.pagelist[areawin->page]->wirewidth * width);
+   tmpwidth = UTopTransScale(width);
    minwidth = max(1, (short)tmpwidth);
 
    if (style & FILLED || (!(style & FILLED) && style & OPAQUE)) {
@@ -2212,12 +2209,15 @@ void makesplinepath(splineptr thespline, XPoint *pathlist)
 
 /*-------------------------------------------------------------------------*/
 
-void UDrawSpline(splineptr thespline)
+void UDrawSpline(splineptr thespline, float passwidth)
 {
    XPoint       tmppoints[SPLINESEGS];
+   float	scaledwidth;
+
+   scaledwidth = thespline->width * passwidth;
 
    makesplinepath(thespline, tmppoints);
-   strokepath(tmppoints, SPLINESEGS, thespline->style, thespline->width);
+   strokepath(tmppoints, SPLINESEGS, thespline->style, scaledwidth);
    if (thespline->cycle != NULL) {
       UDrawXLine(thespline->ctrl[0], thespline->ctrl[1]);  
       UDrawXLine(thespline->ctrl[3], thespline->ctrl[2]);
@@ -2226,34 +2226,41 @@ void UDrawSpline(splineptr thespline)
 
 /*-------------------------------------------------------------------------*/
 
-void UDrawPolygon(polyptr thepoly)
+void UDrawPolygon(polyptr thepoly, float passwidth)
 {
    XPoint *tmppoints = (pointlist) malloc(thepoly->number * sizeof(XPoint));
+   float scaledwidth;
+
+   scaledwidth = thepoly->width * passwidth;
 
    UTransformbyCTM(DCTM, thepoly->points, tmppoints, thepoly->number);
-   strokepath(tmppoints, thepoly->number, thepoly->style, thepoly->width);
+   strokepath(tmppoints, thepoly->number, thepoly->style, scaledwidth);
    free(tmppoints);
 }
 
 /*-------------------------------------------------------------------------*/
 
-void UDrawArc(arcptr thearc)
+void UDrawArc(arcptr thearc, float passwidth)
 {
    XPoint  tmppoints[RSTEPS + 2];
+   float scaledwidth;
+
+   scaledwidth = thearc->width * passwidth;
 
    UfTransformbyCTM(DCTM, thearc->points, tmppoints, thearc->number);
-   strokepath(tmppoints, thearc->number, thearc->style, thearc->width);
+   strokepath(tmppoints, thearc->number, thearc->style, scaledwidth);
 }
 
 /*-------------------------------------------------------------------------*/
 
-void UDrawPath(pathptr thepath)
+void UDrawPath(pathptr thepath, float passwidth)
 {
    XPoint	*tmppoints = (pointlist) malloc(sizeof(XPoint));
    genericptr	*genpath;
    polyptr	thepoly;
    splineptr	thespline;
    int		pathsegs = 0, curseg = 0;
+   float scaledwidth;
    
    for (genpath = thepath->plist; genpath < thepath->plist + thepath->parts;
 	  genpath++) {
@@ -2279,7 +2286,9 @@ void UDrawPath(pathptr thepath)
 	    break;
       }
    } 
-   strokepath(tmppoints, pathsegs, thepath->style, thepath->width);
+   scaledwidth = thepath->width * passwidth;
+
+   strokepath(tmppoints, pathsegs, thepath->style, scaledwidth);
    free(tmppoints);
 }
 
@@ -2289,9 +2298,11 @@ void UDrawPath(pathptr thepath)
 /*    theinstance is the object instance to be drawn			*/
 /*    level is the level of recursion 					*/
 /*    passcolor is the inherited color value passed to object		*/
+/*    passwidth is the inherited linewidth value passed to the object	*/
 /*----------------------------------------------------------------------*/
 
-void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr *stack)
+void UDrawObject(objinstptr theinstance, short level, int passcolor,
+		float passwidth, pushlistptr *stack)
 {
    genericptr	*areagen;
    float	tmpwidth;
@@ -2320,6 +2331,9 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
        UPreMultCTM(DCTM, theinstance->position, theinstance->scale,
 			theinstance->rotation);
 
+   if (theinstance->style & LINE_INVARIANT)
+      passwidth /= fabs(theinstance->scale);
+
    /* do a quick test for intersection with the display window */
 
    bboxin[0].x = theobject->bbox.lowerleft.x;
@@ -2341,7 +2355,7 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
 
      /* draw all of the elements */
    
-     tmpwidth = UTopTransScale(xobjs.pagelist[areawin->page]->wirewidth);
+     tmpwidth = UTopTransScale(passwidth);
      SetLineAttributes(dpy, areawin->gc, tmpwidth, LineSolid, CapRound,
 		JoinBevel);
 
@@ -2366,19 +2380,19 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
        switch(ELEMENTTYPE(*areagen)) {
 	  case(POLYGON):
 	     if (level == 0 || !((TOPOLY(areagen))->style & BBOX))
-                UDrawPolygon(TOPOLY(areagen));
+                UDrawPolygon(TOPOLY(areagen), passwidth);
 	     break;
    
 	  case(SPLINE):
-             UDrawSpline(TOSPLINE(areagen));
+             UDrawSpline(TOSPLINE(areagen), passwidth);
 	     break;
    
 	  case(ARC):
-             UDrawArc(TOARC(areagen));
+             UDrawArc(TOARC(areagen), passwidth);
 	     break;
 
 	  case(PATH):
-	     UDrawPath(TOPATH(areagen));
+	     UDrawPath(TOPATH(areagen), passwidth);
 	     break;
 
 	  case(GRAPHIC):
@@ -2398,7 +2412,7 @@ void UDrawObject(objinstptr theinstance, short level, int passcolor, pushlistptr
 		}
 		if ((!alist) || (!blist)) break;
 	     }
-             UDrawObject(TOOBJINST(areagen), level + 1, curcolor, stack);
+             UDrawObject(TOOBJINST(areagen), level + 1, curcolor, passwidth, stack);
 	     break;
    
   	  case(LABEL): 
@@ -2528,6 +2542,7 @@ void TopDoLatex()
    FILE *f;
    float psscale, outscale;
    int tx, ty, width, height;
+   polyptr framebox;
    XPoint origin;
    Boolean checklatex = FALSE;
    char filename[100], extend[10], *dotptr;
@@ -2576,6 +2591,25 @@ void TopDoLatex()
    width = toplevelwidth(areawin->topinstance, &origin.x);
    height = toplevelheight(areawin->topinstance, &origin.y);
 
+   /* Added 10/19/10:  If there is a specified bounding box, let it	*/
+   /* determine the figure origin;  otherwise, the labels will be	*/
+   /* mismatched to the bounding box.					*/
+
+   if ((framebox = checkforbbox(topobject)) != NULL) {
+      int i, maxx, maxy;
+
+      origin.x = maxx = framebox->points[0].x;
+      origin.y = maxy = framebox->points[0].y;
+      for (i = 1; i < framebox->number; i++) {
+	 if (framebox->points[i].x < origin.x) origin.x = framebox->points[i].x;
+	 if (framebox->points[i].x > maxx) maxx = framebox->points[i].x;
+	 if (framebox->points[i].y < origin.y) origin.y = framebox->points[i].y;
+	 if (framebox->points[i].y > maxy) maxy = framebox->points[i].y;
+      }
+      origin.x -= ((width - maxx + origin.x) / 2);
+      origin.y -= ((height - maxy + origin.y) / 2);
+   }
+
    tx = (int)(72 / psscale) - origin.x,
    ty = (int)(72 / psscale) - origin.y;
 
