@@ -271,7 +271,9 @@ extern short printparams(FILE *, objinstptr, short);
 extern void printobjectparams(FILE *, objectptr);
 extern void varcheck(FILE *, short, objectptr, short *, genericptr, u_char);
 extern void varfcheck(FILE *, float, objectptr, short *, genericptr, u_char);
-extern void varpcheck(FILE *, short, objectptr, int, short *, genericptr, u_char);
+extern Boolean varpcheck(FILE *, short, objectptr, int, short *, genericptr, u_char);
+extern Boolean varpathcheck(FILE *, short, objectptr, int, short *,
+		genericptr *, pathptr, u_char);
 extern void getfile(xcWidget, pointertype, caddr_t);
 extern int filecmp(char *, char *);
 extern Boolean nextfilename(void);
@@ -295,8 +297,7 @@ extern char *varpscan(objectptr, char *, short *, genericptr, int, int, u_char);
 extern char *varscan(objectptr, char *, short *, genericptr, u_char);
 extern char *varfscan(objectptr, char *, float *, genericptr, u_char);
 extern objinstptr addtoinstlist(int, objectptr, Boolean);
-extern Boolean objectread(FILE *, objectptr, short, short, short, char *,
-		int, TechPtr);
+extern Boolean objectread(FILE *, objectptr, short, short, short, char *, int, TechPtr);
 void importfromlibrary(short, char *, char *);
 objectptr *new_library_object(short, char *, objlistptr *, TechPtr);
 Boolean library_object_unique(short, objectptr, objlistptr);
@@ -440,12 +441,11 @@ extern float UDrawRescaleBox(XPoint *);
 extern void UDrawBBox(void);
 extern void strokepath(XPoint *, short, short, float);
 extern void makesplinepath(splineptr, XPoint *);
-extern void UDrawSpline(splineptr);
-extern void UDrawEditSpline(splineptr);
-extern void UDrawPolygon(polyptr);
-extern void UDrawArc(arcptr);
-extern void UDrawPath(pathptr);
-extern void UDrawObject(objinstptr, short, int, pushlistptr *);
+extern void UDrawSpline(splineptr, float);
+extern void UDrawPolygon(polyptr, float);
+extern void UDrawArc(arcptr, float);
+extern void UDrawPath(pathptr, float);
+extern void UDrawObject(objinstptr, short, int, float, pushlistptr *);
 extern void TopDoLatex(void);
 
 /* from help.c: */
@@ -948,10 +948,10 @@ extern Boolean pin_is_bus(labelptr, objinstptr);
 extern int find_cardinal(int, labelptr, objinstptr);
 extern int find_ordinal(int, labelptr, objinstptr);
 
-extern short UDrawChar(u_char, short, short, int, int);
+extern short UDrawChar(u_char, short, short, int, int, float);
 extern void UDrawString(labelptr, int, objinstptr);
 extern void UDrawStringNoX(labelptr, int, objinstptr);
-extern TextExtents ULength(labelptr, objinstptr, float, short, XPoint *);
+extern TextExtents ULength(labelptr, objinstptr, short, XPoint *);
 extern void undrawtext(labelptr);
 extern void redrawtext(labelptr);
 extern void composefontlib(short);
